@@ -47,11 +47,13 @@ async def wait_for_server(host, port, timeout=10):
 
 async def start_server(configs: Config):
     assert configs.db_path is not None
-    if not os.path.isdir(os.path.expanduser(configs.db_path)):
+    db_path = os.path.expanduser(configs.db_path)
+    if not os.path.isdir(db_path):
         print(
-            f"Creating database at {os.path.expanduser('~/.local/share/vectorcode/chromadb/')}.",
+            f"Using local database at {os.path.expanduser('~/.local/share/vectorcode/chromadb/')}.",
             file=sys.stderr,
         )
+        db_path = os.path.expanduser("~/.local/share/vectorcode/chromadb/")
     env = os.environ.copy()
     with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
         s.bind(("", 0))  # OS selects a free ephemeral port
@@ -68,7 +70,7 @@ async def start_server(configs: Config):
             "--port",
             str(configs.port),
             "--path",
-            str(configs.db_path),
+            db_path,
             "--log-path",
             os.path.join(str(configs.project_root), "chroma.log"),
         ],
@@ -125,20 +127,30 @@ def get_embedding_function(configs: Config) -> chromadb.EmbeddingFunction:
         return embedding_functions.SentenceTransformerEmbeddingFunction()
 
 
-async def make_or_get_collection(client: AsyncClientAPI, configs: Config):
+async def get_collection(
+    client: AsyncClientAPI, configs: Config, make_if_missing: bool = False
+):
+    """
+    Raise ValueError when make_if_missing is False and no collection is found;
+    Raise IndexError on hash collision.
+    """
     full_path = str(expand_path(str(configs.project_root), absolute=True))
+    collection_name = get_collection_name(full_path)
+    embedding_function = get_embedding_function(configs)
+    collection_meta = {
+        "path": full_path,
+        "hostname": socket.gethostname(),
+        "created-by": "VectorCode",
+        "username": os.environ.get("USER", os.environ.get("USERNAME", "DEFAULT_USER")),
+        "embedding_function": configs.embedding_function,
+    }
+
+    if not make_if_missing:
+        return await client.get_collection(collection_name, embedding_function)
     collection = await client.get_or_create_collection(
-        get_collection_name(full_path),
-        metadata={
-            "path": full_path,
-            "hostname": socket.gethostname(),
-            "created-by": "VectorCode",
-            "username": os.environ.get(
-                "USER", os.environ.get("USERNAME", "DEFAULT_USER")
-            ),
-            "embedding_function": configs.embedding_function,
-        },
-        embedding_function=get_embedding_function(configs),
+        collection_name,
+        metadata=collection_meta,
+        embedding_function=embedding_function,
     )
     if (
         not collection.metadata.get("hostname") == socket.gethostname()
